@@ -1,7 +1,11 @@
 from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
 
 
-def pagination(request, obj_list, obj_count=20):
+def pagination(request, obj_list, obj_count=10):
+    try:
+        obj_list = list(obj_list)
+    except:
+        raise ValueError("object is not iterable")
     page = request.GET.get('page', 1)
     paginator = Paginator(obj_list, obj_count)
     try:
